Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(134)

Unified Diff: ash/ash_switches.cc

Issue 2825383003: Fix stylus tools palette. (Closed)
Patch Set: Rebase and update the enums.xml file. Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/ash_switches.cc
diff --git a/ash/ash_switches.cc b/ash/ash_switches.cc
index 4ec343dd53900dd6f628512c2afcbe356cb1f4cd..0f55bdfefbebcc901c1dbc37f1bd696d60dff55c 100644
--- a/ash/ash_switches.cc
+++ b/ash/ash_switches.cc
@@ -67,8 +67,8 @@ const char kAshDisableSmoothScreenRotation[] =
const char kAshEstimatedPresentationDelay[] =
"ash-estimated-presentation-delay";
-// Enables the palette next to the status area.
-const char kAshForceEnablePalette[] = "ash-force-enable-palette";
+// Enables the stylus tools next to the status area.
+const char kAshForceEnableStylusTools[] = "force-enable-stylus-tools";
// Enables required things for the selected UI mode, regardless of whether the
// Chromebook is currently in the selected UI mode.

Powered by Google App Engine
This is Rietveld 408576698